macro_rules! cbor_bool {
( $x:expr ) => { ... };
}Expand description
Creates a CBOR Value of type Simple with the given bool value.
macro_rules! cbor_bool {
( $x:expr ) => { ... };
}Creates a CBOR Value of type Simple with the given bool value.