Module reader

Module reader 

Functionality for deserializing CBOR data into values.

Enums

DecoderError
Possible errors from a deserialization operation.

Functions

read
Deserialize CBOR binary data to produce a single Value, expecting that there is no additional data. Maximum level of nesting supported is 127; more deeply nested structures will fail with DecoderError::TooMuchNesting.
read_nested
Deserialize CBOR binary data to produce a single Value, expecting that there is no additional data. If max_nest is Some(max), then nested structures are only supported up to the given limit (returning DecoderError::TooMuchNesting if the limit is hit).
read_nested_non_strict
Deserialize CBOR binary data to produce a single Value. If max_nest is Some(max), then nested structures are only supported up to the given limit (returning DecoderError::TooMuchNesting if the limit is hit).