write_nested

Function write_nested 

pub fn write_nested(
    value: Value,
    encoded_cbor: &mut Vec<u8>,
    max_nest: Option<i8>,
) -> Result<(), EncoderError>
Convert a Value to serialized CBOR data, consuming it along the way and appending to the provided vector. If max_nest is Some(max), then nested structures are only supported up to the given limit (returning [DecoderError::TooMuchNesting] if the limit is hit).