Functionality for deserializing CBOR data into values.
Enums
- Decoder
Error - Possible errors from a deserialization operation.
Functions
- read
- Deserialize CBOR binary data to produce a single
Value, expecting that there is no additional data. Maximum level of nesting supported is 127; more deeply nested structures will fail withDecoderError::TooMuchNesting. - read_
nested - Deserialize CBOR binary data to produce a single
Value, expecting that there is no additional data. Ifmax_nestisSome(max), then nested structures are only supported up to the given limit (returningDecoderError::TooMuchNestingif the limit is hit). - read_
nested_ non_ strict - Deserialize CBOR binary data to produce a single
Value. Ifmax_nestisSome(max), then nested structures are only supported up to the given limit (returningDecoderError::TooMuchNestingif the limit is hit).